pub struct Frame {
pub source: Box<dyn StdError + Send + Sync + 'static>,
pub location: &'static Location<'static>,
}Expand description
A single layer of error context.
Contains the source error that caused this context layer, along with the location where the context was added. Created automatically by the conversion functions when an error occurs.
Creation
Frame is typically created via From<T> where T can be
converted to Box<dyn Error + Send + Sync>. The location is captured
using #[track_caller].
Fields
source: Box<dyn StdError + Send + Sync + 'static>The underlying error that caused this context.
location: &'static Location<'static>The location where this context was attached.